import type { IConstruct } from "constructs";
import type { Manifest } from "./manifest";
import type { Workflow } from "./workflow";
/**
 * Represents the session for synthesizing workflows, including output directory and validation options.
 */
export interface ISynthesisSession {
    /**
     * The output directory where synthesized YAML files will be stored.
     */
    readonly outdir: string;
    /**
     * Indicates whether to skip validation during synthesis.
     *
     * @default false
     */
    readonly skipValidation?: boolean;
    /**
     * The manifest that records synthesized workflows.
     */
    readonly manifest: Manifest;
}
/**
 * Interface for synthesizers that handle workflow synthesis.
 */
export interface IWorkflowSynthesizer {
    /**
     * Synthesizes a workflow into the specified output format.
     *
     * @param session - The synthesis session containing configuration for the synthesis process.
     */
    synthesize(session: ISynthesisSession): void;
}
/**
 * Handles the synthesis of a GitHub Actions workflow, generating YAML output.
 */
export declare class WorkflowSynthesizer implements IWorkflowSynthesizer {
    protected workflow: Workflow;
    private continueOnErrorAnnotations;
    /**
     * Creates a new instance of WorkflowSynthesizer.
     *
     * @param workflow - The workflow to be synthesized.
     * @param continueOnErrorAnnotations - Indicates whether to continue processing on error annotations.
     */
    constructor(workflow: Workflow, continueOnErrorAnnotations?: boolean);
    /**
     * Synthesizes the workflow into a YAML file.
     *
     * This process includes invoking aspects, validating the workflow,
     * checking annotations, and writing the output to a file.
     *
     * @param session - The synthesis session containing configuration for the synthesis process.
     */
    synthesize(session: ISynthesisSession): void;
    /**
     * Invokes all aspects associated with the workflow.
     */
    private invokeAspects;
    /**
     * Validates the workflow, checking for any errors in the construct tree.
     *
     * @throws {Error} If validation errors are found.
     */
    private validate;
    /**
     * Checks for annotations in the workflow and processes error annotations.
     *
     * @returns An array of workflow annotations.
     * @throws {Error} If there are error annotations and continuation is not allowed.
     */
    private checkAnnotations;
    /**
     * Collects validation errors from the workflow's constructs.
     *
     * @returns An array of validation error messages along with their source constructs.
     */
    private collectValidationErrors;
    /**
     * Throws an error if validation fails, providing details of the errors.
     *
     * @param errors - The validation errors to report.
     * @throws {Error} With details of the validation failures.
     */
    private throwValidationError;
    /**
     * Collects annotations from the workflow's constructs.
     *
     * @returns An array of workflow annotations.
     */
    private collectAnnotations;
}
/**
 * Invokes aspects on a construct and its children, ensuring that aspects are applied correctly.
 *
 * @param root - The root construct for which aspects should be invoked.
 */
export declare function invokeAspects(root: IConstruct): void;
